ProSHADE: Class Members

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

Here is a list of all documented class members with links to the class documentation for each member:

### - s -

- saveDetectedSymmetries() : ProSHADE_internal_data::ProSHADE_data
- saveMask : ProSHADE_settings
- saveRecommendedSymmetry() : ProSHADE_internal_data::ProSHADE_data
- saveRequestedSymmetryC() : ProSHADE_internal_data::ProSHADE_data
- saveRequestedSymmetryD() : ProSHADE_internal_data::ProSHADE_data
- setAxisComparisonThreshold() : ProSHADE_settings
- setAxisComparisonThresholdBehaviour() : ProSHADE_settings
- setBandwidth() : ProSHADE_settings
- setBicubicInterpolationSearch() : ProSHADE_settings
- setBoundsSpace() : ProSHADE_settings
- setBoundsThreshold() : ProSHADE_settings
- setCorrelationMasking() : ProSHADE_settings
- setDetectedSymmetry() : ProSHADE_settings
- setEMatrixValue() : ProSHADE_internal_data::ProSHADE_data
- setEnergyLevelsComputation() : ProSHADE_settings
- setEnLevShellWeight() : ProSHADE_settings
- setExtraSpace() : ProSHADE_settings
- setGroupingSmoothingFactor() : ProSHADE_settings
- setIntegrationOrder() : ProSHADE_settings
- setIntegrationWeight() : ProSHADE_internal_data::ProSHADE_data
- setIntegrationWeightCumul() : ProSHADE_internal_data::ProSHADE_data
- setMapCentering() : ProSHADE_settings
- setMapInversion() : ProSHADE_settings
- setMapReboxing() : ProSHADE_settings
- setMapResolutionChange() : ProSHADE_settings
- setMapResolutionChangeTriLinear() : ProSHADE_settings
- setMaskBlurFactor() : ProSHADE_settings
- setMaskFilename() : ProSHADE_settings
- setMasking() : ProSHADE_settings
- setMaskIQR() : ProSHADE_settings
- setMaskSaving() : ProSHADE_settings
- setMaxSymmetryFold() : ProSHADE_settings
- setMinimumMaskSize() : ProSHADE_settings
- setMinimumPeakForAxis() : ProSHADE_settings
- setMissingPeakThreshold() : ProSHADE_settings
- setNormalisation() : ProSHADE_settings
- setOutputFilename() : ProSHADE_settings
- setOverlayJsonFile() : ProSHADE_settings
- setOverlaySaveFile() : ProSHADE_settings
- setPDBBFactor() : ProSHADE_settings
- setPDBMapValues() : ProSHADE_internal_data::ProSHADE_data
- setPeakNaiveNoIQR() : ProSHADE_settings
- setPeakNeighboursNumber() : ProSHADE_settings
- setPhaseUsage() : ProSHADE_settings
- setProgressiveSphereMapping() : ProSHADE_settings
- setRecommendedFold() : ProSHADE_settings
- setRecommendedSymmetry() : ProSHADE_settings
- setRequestedFold() : ProSHADE_settings
- setRequestedSymmetry() : ProSHADE_settings
- setResolution() : ProSHADE_settings
- setRotatedMappedData() : ProSHADE_internal_spheres::ProSHADE_sphere
- setRotationFunctionComputation() : ProSHADE_settings
- setSameBoundaries() : ProSHADE_settings
- setSO3CoeffValue() : ProSHADE_internal_data::ProSHADE_data
- setSphereDistances() : ProSHADE_settings
- setSymmetryRotFunPeaks() : ProSHADE_settings
- setTaylorSeriesCap() : ProSHADE_settings
- setTraceSigmaComputation() : ProSHADE_settings
- setTypicalNoiseSize() : ProSHADE_settings
- setVariablesLeftOnAuto() : ProSHADE_settings
- setVerbosity() : ProSHADE_settings
- setWignerMatrixValue() : ProSHADE_internal_data::ProSHADE_data
- shellBandExists() : ProSHADE_internal_data::ProSHADE_data
- smoothingFactor : ProSHADE_settings
- so3Coeffs : ProSHADE_internal_data::ProSHADE_data
- so3CoeffsArrayIndex() : ProSHADE_internal_data::ProSHADE_data
- so3CoeffsInverse : ProSHADE_internal_data::ProSHADE_data
- spherePos : ProSHADE_internal_data::ProSHADE_data
- spheres : ProSHADE_internal_data::ProSHADE_data
- sphericalHarmonics : ProSHADE_internal_data::ProSHADE_data
- symMissPeakThres : ProSHADE_settings